@@ -88,7 +88,10 @@ GType gda_xa_transaction_get_type(void);
 
 GQuark gda_connection_error_quark(void);
 GQuark gda_data_model_iter_error_quark(void);
+GQuark gda_holder_error_quark(void);
 GQuark gda_server_provider_error_quark(void);
+GQuark gda_sql_parser_error_quark(void);
+GQuark gda_statement_error_quark(void);
 } // extern "C"
 
 
@@ -132,7 +135,10 @@ void wrap_init()
   // Register Error domains:
   Glib::Error::register_domain(gda_connection_error_quark(), &Gnome::Gda::ConnectionError::throw_func);
   Glib::Error::register_domain(gda_data_model_iter_error_quark(), &Gnome::Gda::DataModelIterError::throw_func);
+  Glib::Error::register_domain(gda_holder_error_quark(), &Gnome::Gda::HolderError::throw_func);
   Glib::Error::register_domain(gda_server_provider_error_quark(), &Gnome::Gda::ServerProviderError::throw_func);
+  Glib::Error::register_domain(gda_sql_parser_error_quark(), &Gnome::Gda::SqlParserError::throw_func);
+  Glib::Error::register_domain(gda_statement_error_quark(), &Gnome::Gda::StatementError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gda_batch_get_type(), &Gnome::Gda::Batch_Class::wrap_new);
